@@ -399,6 +399,32 @@ def cancel_campaign(ctx: click.Context, campaign_id: str, yes: bool) -> None:
         ctx.exit(1)
 
 
+@campaigns.command("schedule")
+@click.argument("campaign_id")
+@click.option(
+    "--scheduled-at",
+    help="When to send (ISO format, e.g., 2024-01-15T10:00:00)",
+)
+@click.pass_context
+def schedule_campaign(
+    ctx: click.Context,
+    campaign_id: str,
+    scheduled_at: Optional[str],
+) -> None:
+    """Schedule or reschedule a campaign."""
+    try:
+        client = get_client(ctx.obj["api_key"], ctx.obj["base_url"])
+        campaign = client.campaigns.schedule(campaign_id, scheduled_at)
+
+        click.echo("✓ Campaign scheduled successfully!")
+        click.echo("Details:")
+        click.echo(campaign.model_dump_json(indent=2))
+
+    except Exception as e:
+        click.echo(f"✗ Error scheduling campaign: {e}", err=True)
+        ctx.exit(1)
+
+
 @campaigns.command("add-ltv")
 @click.argument("campaign_id")
 @click.option(
@@ -551,3 +577,32 @@ def new_email_campaign(
     except Exception as e:
         click.echo(f"✗ Error creating email campaign: {e}", err=True)
         ctx.exit(1)
+
+
+@campaigns.command("send-test-email")
+@click.argument("campaign_id")
+@click.option(
+    "--email",
+    "-e",
+    "email_address",
+    required=True,
+    help="Email address to send test email to",
+)
+@click.pass_context
+def send_test_email(
+    ctx: click.Context,
+    campaign_id: str,
+    email_address: str,
+) -> None:
+    """Send a test email for the specified email campaign."""
+    try:
+        client = get_client(ctx.obj["api_key"], ctx.obj["base_url"])
+        result = client.campaigns.send_test_email(campaign_id, email_address)
+
+        click.echo("✓ Test email sent successfully!")
+        click.echo(f"  Sent to: {email_address}")
+        click.echo(f"  Response: {result}")
+
+    except Exception as e:
+        click.echo(f"✗ Error sending test email: {e}", err=True)
+        ctx.exit(1)
