@@ -125,6 +125,23 @@ def setup_account(
         ctx.exit(1)
 
 
+@accounts.command("check-status")
+@click.pass_context
+def check_account_status(ctx: click.Context) -> None:
+    """Check the status of email accounts."""
+    try:
+        client = get_client(ctx.obj["api_key"], ctx.obj["base_url"])
+
+        status_info = client.email_accounts.check_status()
+
+        click.echo("✓ Email account status:")
+        click.echo(status_info)
+
+    except Exception as e:
+        click.echo(f"✗ Error checking email account status: {e}", err=True)
+        ctx.exit(1)
+
+
 @accounts.command("create")
 @click.option("--name", "-n", required=True, help="Account name")
 @click.option("--from-email", help="Default from email address")
@@ -463,6 +480,36 @@ def delete_channel(
         ctx.exit(1)
 
 
+@channels.command("set-engagement-tracking")
+@click.argument("channel_id")
+@click.option(
+    "--enable/--disable",
+    default=True,
+    help="Enable or disable engagement tracking (default: enable)",
+)
+@click.pass_context
+def set_engagement_tracking(
+    ctx: click.Context,
+    channel_id: str,
+    enable: bool,
+) -> None:
+    """Enable or disable engagement tracking for an email channel."""
+    try:
+        client = get_client(ctx.obj["api_key"], ctx.obj["base_url"])
+        channel = client.email_channels.set_engagement_tracking(
+            channel_id, enable
+        )
+
+        status = "enabled" if enable else "disabled"
+        click.echo(f"✓ Engagement tracking {status} for channel {channel_id}")
+        click.echo("Details:")
+        click.echo(channel.model_dump_json(indent=2))
+
+    except Exception as e:
+        click.echo(f"✗ Error setting engagement tracking: {e}", err=True)
+        ctx.exit(1)
+
+
 # Email Identities Commands
 @email.group()
 def identities() -> None:
@@ -819,9 +866,6 @@ def send_email(
             click.echo(f"Template ID: {result.template_id}")
 
     except Exception as e:
-        import traceback
-
-        traceback.print_exc()
         click.echo(f"✗ Error sending email: {e}", err=True)
         ctx.exit(1)
 
