@@ -113,6 +113,14 @@ class EmailChannel(BaseEmailChannel, TimestampedResource):
     )
     """Rate limit (emails per second) for this channel."""
 
+    enable_engagement_tracking: bool = Field(
+        default=False,
+        title="Engagement Tracking",
+        description="Whether engagement tracking (open and click) is "
+        "enabled for this channel.",
+    )
+    """Whether engagement tracking is enabled for this channel."""
+
     def __str__(self) -> str:
         return (
             f"EmailChannel(id = {self.id} code={self.code} "
