@@ -82,6 +82,13 @@ class EmailTemplate(BaseEmailTemplate, TimestampedResource):
     )
     """ID of the email account this template belongs to."""
 
+    preview_url: Optional[str] = Field(
+        default=None,
+        title="Preview URL",
+        description="URL to preview the rendered email template.",
+    )
+    """URL to preview the rendered email template."""
+
     def __str__(self) -> str:
         return (
             f"EmailTemplate(id={self.id} name={self.name} "
